@@ -18,7 +18,7 @@ def default_jinja_env(template_path: str = None):
         template_path = DEFAULT_TEMPLATE_PATH
 
     return Environment(
-        loader=FileSystemLoader(template_path),
+        loader=FileSystemLoader([os.getcwd(), template_path]),
         autoescape=select_autoescape(['sql'])
     )
 
@@ -38,6 +38,8 @@ def render(name: str, jinja_env: Environment=None, **context):
 
     if not context:
         context = default_jinja_context
+    else:
+        context = {**context, **default_jinja_context}
 
     for path in jinja_env.loader.searchpath:
         name = name.replace(path, '')
